!> \brief Reads initial conditions file generated using makeinitial.
!!
!! Reads the projectname.ini file created using the tool \a makeinitial
!! or generated by the user. The file is read and each variable is 
!! checked to see if it has been defined by the user (if min and max are
!! zero then it is considered not defined by the user). If a variable
!! has not been defined by the user, a flag is set. 
!!
!! E.g. if all velocity !components are found to be zero then
!! SetAutoVelocity = .TRUE.
SUBROUTINE read_initial(error)
  USE precision
  USE constants
  USE general_funcs
  USE string_funcs

  USE global_variables

  Implicit none
  Integer, Intent(out):: error

  Integer:: iunit, ii, n, ip, nc
  Character(Len=80):: filename
  Logical:: filexist

  Character(Len=1):: version_control
  Integer:: initial_version

  filexist = .false.
  error    = 0

  iunit = 88
  filename = TRIM(upper_to_lower(projectname))//".ini"
  INQUIRE(FILE=filename,EXIST=filexist)
   !
  !-----------------------------!
  !- No Initial File available -!
  !-----------------------------!
  If (.not.filexist) then
    write(*,*)' '
    write(*,*)'  Initial conditions file ',TRIM(filename),' not found'
    write(*,*)'    *Setting automatic initial conditions'

    write(icstd,*)
    write(icstd,*)'*Initial conditions file ',TRIM(filename),' not found'
    write(icstd,*)' Setting automatic initial conditions'

    If (InflowBCType2Exists) Then
      write(*,*)
      write(*,*)'****************************************************'
      write(*,*)'* WARNING: Inflow BCs that are to be defined using *'
      write(*,*)'*   initial conditions found (bnd_inflow_type = 2) *'
      write(*,*)'* But no initial conditions (*.ini) found          *'
      write(*,*)'* Will result in zero inflow velocities for Type 2 *'
      write(*,*)'* inflows...                                       *'
      write(*,*)'****************************************************'
      call SLEEP(5)
    Endif

    filexist = .false.
     !
    SetAutoPressure      = .true.
    SetAutoVelocity      = .true.
    SetAutoTemperature   = .true.
    SetAutoConcentration = .true.
    SetAutoTurbulence    = .true.
    SetAutoLSet          = .true.
    SetAutoLVoF          = .true.
    SetAutoMixture       = .true.

    Return    !*<--don't go further
  Endif

  !--------------------!
  ! Report in Log file !
  !--------------------!
  call blankline(icstd)
  call separator(icstd,24,'=',1)
  write(icstd,13)
  13 Format(' == Initial conditions ==')
  call separator(icstd,24,'=',1)

  Open(iunit,file=filename,status="old",form="unformatted")

  initial_version = 0

  !------------------------------------!
  !- check if there is version control !
  !------------------------------------!
  version_control = ' '
  Read(iunit)version_control
  if (TRIM(version_control) == 'v') then
    read(iunit)initial_version
  else
    REWIND(iunit)
  endif

  write(icstd,14)initial_version
  14 Format('  Version: ',I5)

  !-----------------!
  ! version control !
  !-----------------!
  Select Case(initial_version)
  Case (1)
    call read_initial_v1(iunit,error)
    if (error /= 0) Return
  Case Default
    call read_initial_v0(iunit,error)
    if (error /= 0) Return
  End select

  !----------------------------------------------------------!
  !- Special checks for Scalars (temperature/concentration) -!
  !- Should not be set automatically unless implicit/steady -!
  !----------------------------------------------------------!
  If (.NOT.(Solve_Implicit.AND.Steady)) Then
    SetAutoTemperature   = .false.
    SetAutoConcentration = .false.
    SetAutoMixture       = .false.
    write(icstd,*)
    write(icstd,*)' For unsteady flow T/C are not set automatically '
    write(icstd,*)' Initial conditions could be zero                '
  Endif

  !--------------------------!
  !- Report to Standard Out -!
  !--------------------------!
  write(icstd,*)
  if (SetAutoPressure)       &
    write(icstd,*)'  Pressure will be set automatically'
  if (SetAutoVelocity)       &
    write(icstd,*)'  Velocity will be set automatically'
  if (SetAutoTemperature)    &
    write(icstd,*)'  Temperature will be set automatically'
  if (SetAutoConcentration)  &
    write(icstd,*)'  Concentration will be set automatically'
  if (SetAutoLSet)           &
    write(icstd,*)'  Level-Set will be set automatically'
  if (SetAutoLVoF)           &
    write(icstd,*)'  VoF       will be set automatically'
  if (SetAutoTurbulence)     &
    write(icstd,*)'  Turbulence will be set automatically'
  if (SetAutoMixture)     &
    write(icstd,*)'  Mixture will be set automatically'

  close(iunit)
  write(*,*)'  Initial conditions read successfully'
END SUBROUTINE read_initial
